"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseFunctionArg = void 0;
var console_messages_1 = require("../../../../../cli/console/console.messages");
var translate_graphql_type_to_typescript_1 = require("../../../../parsing/typescript/translate-graphql-type-to-typescript");
var getType = function (queryName, name, fieldType) {
    var _a, _b, _c;
    switch (fieldType.kind) {
        case 'ENUM':
        case 'INPUT_OBJECT':
            return {
                name: name,
                type: fieldType.name,
                imports: (_a = fieldType.name) !== null && _a !== void 0 ? _a : undefined,
            };
        case 'SCALAR':
            return {
                name: name,
                type: (0, translate_graphql_type_to_typescript_1.translateGraphqlTypeToTypescript)(fieldType.name),
            };
        case 'LIST': {
            var ofType = (_b = fieldType === null || fieldType === void 0 ? void 0 : fieldType.ofType) === null || _b === void 0 ? void 0 : _b.ofType;
            if ((ofType === null || ofType === void 0 ? void 0 : ofType.kind) === 'SCALAR') {
                return {
                    name: name,
                    type: (0, translate_graphql_type_to_typescript_1.translateGraphqlTypeToTypescript)(ofType.name),
                };
            }
            return {
                name: name,
                type: "Array<".concat(ofType === null || ofType === void 0 ? void 0 : ofType.name, ">"),
                imports: (_c = fieldType.name) !== null && _c !== void 0 ? _c : undefined,
            };
        }
        default: {
            (0, console_messages_1.displayWarning)("Query replacer: unhandled arg ".concat(name, " for query ").concat(queryName));
            return {
                name: name,
                type: 'unknown',
            };
        }
    }
};
var parseFunctionArg = function (_a) {
    var queryName = _a.queryName, type = _a.type, name = _a.name;
    if (type.kind === 'NON_NULL') {
        return getType(queryName, name, type.ofType);
    }
    return getType(queryName, name, type);
};
exports.parseFunctionArg = parseFunctionArg;
