"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.extractArgsTypes = void 0;
var capitalize_1 = require("../../../util/capitalize");
var parse_graphql_field_1 = require("../object-parsing/field-parsing/parse-graphql-field");
var extractArgsTypes = function (operationType, fields) {
    if (!fields) {
        return [];
    }
    return fields.reduce(function (out, field) {
        if (!field.args || field.args.length === 0) {
            return out;
        }
        var parsedArgs = field.args.map(function (arg) { return (0, parse_graphql_field_1.parseGraphqlField)(arg, true); });
        var typeName = "".concat((0, capitalize_1.capitalize)(field.name)).concat(operationType, "Args");
        var properties = parsedArgs.map(function (arg) { return arg.output; }).join(', ');
        var data = "export type ".concat(typeName, " = { ").concat(properties, " };\n");
        var imports = parsedArgs.map(function (arg) {
            var _a, _b;
            return arg.type.startsWith('Array<')
                ? (_b = (_a = /^Array<(.*)>$/.exec(arg.type)) === null || _a === void 0 ? void 0 : _a[1]) !== null && _b !== void 0 ? _b : ''
                : arg.type;
        });
        out.push({
            type: operationType === 'Query' ? 'queries' : 'mutations',
            name: field.name,
            gqlParams: parsedArgs.map(function (el) { return el.gqlParams; }),
            gqlArgs: parsedArgs.map(function (el) { return el.gqlArgs; }),
            imports: imports,
            data: data,
        });
        return out;
    }, []);
};
exports.extractArgsTypes = extractArgsTypes;
