"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseUnderlyingType = void 0;
var parse_list_1 = require("./list/parse-list");
var console_messages_1 = require("../../../../../../cli/console/console.messages");
var translate_graphql_type_to_typescript_1 = require("../../../../typescript/translate-graphql-type-to-typescript");
var format_field_1 = require("../format/format-field");
var parseUnderlyingType = function (fieldName, type, isFunction, isNull) {
    var _a;
    if (type.kind === 'LIST') {
        var underlying = (_a = type.ofType) === null || _a === void 0 ? void 0 : _a.ofType;
        return (0, parse_list_1.parseList)(underlying === null || underlying === void 0 ? void 0 : underlying.kind, fieldName, underlying === null || underlying === void 0 ? void 0 : underlying.name, isFunction, isNull);
    }
    else if (type.kind === 'OBJECT' ||
        type.kind === 'INPUT_OBJECT' ||
        type.kind === 'ENUM') {
        return {
            output: (0, format_field_1.formatField)(fieldName, type.name, isFunction, isNull),
            type: type.name,
            gqlParams: "$".concat(fieldName, ": ").concat(type.name).concat(isNull ? '' : '!'),
            gqlArgs: "".concat(fieldName, ": $").concat(fieldName),
        };
    }
    else if (type.kind === 'SCALAR') {
        return {
            output: (0, format_field_1.formatField)(fieldName, (0, translate_graphql_type_to_typescript_1.translateGraphqlTypeToTypescript)(type.name), isFunction, isNull),
            type: (0, translate_graphql_type_to_typescript_1.translateGraphqlTypeToTypescript)(type.name),
            gqlParams: "$".concat(fieldName, ": ").concat(type.name).concat(isNull ? '' : '!'),
            gqlArgs: "".concat(fieldName, ": $").concat(fieldName),
        };
    }
    (0, console_messages_1.displayWarning)("Unhandled field ".concat(fieldName, " of type ").concat(type));
    return { output: '', type: '', gqlParams: '', gqlArgs: '' };
};
exports.parseUnderlyingType = parseUnderlyingType;
